#!/usr/bin/env bash

ABSDIR="$( dirname "$(readlink -f -- "$0")" )"
source ${ABSDIR}/../functions.sh
source ${ABSDIR}/vars.sh

ensure_pwd_is_scriptdir
ensure_not_root

buildfolder=/tmp/hedgedoc-$$

if ! podman image exists ${hedgedoc_image}:${hedgedoc_version}; then
    mkdir ${buildfolder} &&
        git clone --depth=1 https://github.com/hedgedoc/container ${buildfolder}/ && {
	sed_in_place "^FROM node" "FROM docker.io/library/node" ${buildfolder}/alpine/Dockerfile
	TMPDIR=${HOME} podman image build -t ${hedgedoc_image}:${hedgedoc_version} --build-arg VERSION=${hedgedoc_version/%-alpine/} -f ${buildfolder}/alpine/Dockerfile ${buildfolder}
    }
    rm -rf ${buildfolder}
    podman image prune -a -f --filter dangling=true
    podman image prune -a -f --filter intermediate=true
    podman image rm -f $(podman images -a -q -- docker.io/library/node)
else
    echo "Image ${hedgedoc_image}:${hedgedoc_version} already built"
fi

oci_push_to_registry ${hedgedoc_image}:${hedgedoc_version}
